@@ -37,10 +37,13 @@ import dbus.glib
 import dbus.mainloop.glib
 dbus.mainloop.glib.DBusGMainLoop(set_as_default=True)
 
-if 'gi.repository' in sys.modules:
-    from gi.repository import GObject
-else:
+if 'gobject' in sys.modules and sys.modules['gobject'] is not None:
     import gobject as GObject
+    GLib = GObject
+    _GObject = GObject.GObject
+else:
+    from gi.repository import GObject, GLib
+    _GObject = GObject.Object
 
 from . import enums
 from . import debconf
@@ -51,28 +54,7 @@ from .errors import convert_dbus_exception, TransactionFailed
 __all__ = ("AptTransaction", "AptClient", "get_transaction", "get_aptdaemon")
 
 
-class MemoizedTransaction(type):
-
-    """Metaclass to cache transactions."""
-
-    cache = weakref.WeakValueDictionary()
-
-    def __call__(mcs, *args):
-        tid = args[0]
-        try:
-            return mcs.cache[tid]
-        except KeyError:
-            mcs.cache[tid] = value = \
-                    super(MemoizedTransaction, mcs).__call__(*args)
-            return value
-
-
-class MemoizedMixIn(MemoizedTransaction, GObject.GObjectMeta):
-
-    """Helper meta class for merging"""
-
-
-class AptTransaction(GObject.GObject):
+class AptTransaction(_GObject):
 
     """Represents an aptdaemon transaction.
 
@@ -410,8 +392,6 @@ class AptTransaction(GObject.GObject):
         dependencies before the transaction will be executed.
     """
 
-    __metaclass__ = MemoizedMixIn
-
     __gsignals__ = {"finished": (GObject.SIGNAL_RUN_FIRST,
                                  GObject.TYPE_NONE,
                                  (GObject.TYPE_STRING,)),
@@ -437,8 +417,8 @@ class AptTransaction(GObject.GObject):
                                      GObject.TYPE_NONE,
                                      (GObject.TYPE_STRING,)),
                     "terminal-attached-changed": (GObject.SIGNAL_RUN_FIRST,
-                                                    GObject.TYPE_NONE,
-                                                    (GObject.TYPE_BOOLEAN,)),
+                                                  GObject.TYPE_NONE,
+                                                  (GObject.TYPE_BOOLEAN,)),
                     "cancellable-changed": (GObject.SIGNAL_RUN_FIRST,
                                             GObject.TYPE_NONE,
                                             (GObject.TYPE_BOOLEAN,)),
@@ -452,23 +432,24 @@ class AptTransaction(GObject.GObject):
                                                GObject.TYPE_NONE,
                                                (GObject.TYPE_STRING,)),
                     "progress-changed": (GObject.SIGNAL_RUN_FIRST,
-                                 GObject.TYPE_NONE,
-                                 (GObject.TYPE_INT,)),
+                                         GObject.TYPE_NONE,
+                                         (GObject.TYPE_INT,)),
                     "progress-details-changed": (GObject.SIGNAL_RUN_FIRST,
-                                         GObject.TYPE_NONE,
-                                         (GObject.TYPE_INT, GObject.TYPE_INT,
-                                          GObject.TYPE_INT64,
-                                          GObject.TYPE_INT64,
-                                          GObject.TYPE_INT,
-                                          GObject.TYPE_INT64)),
+                                                 GObject.TYPE_NONE,
+                                                 (GObject.TYPE_INT,
+                                                  GObject.TYPE_INT,
+                                                  GObject.TYPE_INT64,
+                                                  GObject.TYPE_INT64,
+                                                  GObject.TYPE_INT,
+                                                  GObject.TYPE_INT64)),
                     "progress-download-changed": (GObject.SIGNAL_RUN_FIRST,
-                                         GObject.TYPE_NONE,
-                                         (GObject.TYPE_STRING,
-                                          GObject.TYPE_STRING,
-                                          GObject.TYPE_STRING,
-                                          GObject.TYPE_INT64,
-                                          GObject.TYPE_INT64,
-                                          GObject.TYPE_STRING)),
+                                                  GObject.TYPE_NONE,
+                                                  (GObject.TYPE_STRING,
+                                                   GObject.TYPE_STRING,
+                                                   GObject.TYPE_STRING,
+                                                   GObject.TYPE_INT64,
+                                                   GObject.TYPE_INT64,
+                                                   GObject.TYPE_STRING)),
                     "packages-changed": (GObject.SIGNAL_RUN_FIRST,
                                          GObject.TYPE_NONE,
                                          (GObject.TYPE_PYOBJECT,
@@ -479,8 +460,7 @@ class AptTransaction(GObject.GObject):
                                           GObject.TYPE_PYOBJECT)),
                     "unauthenticated-changed": (GObject.SIGNAL_RUN_FIRST,
                                                 GObject.TYPE_NONE,
-                                                (GObject.TYPE_PYOBJECT,
-                                                 )),
+                                                (GObject.TYPE_PYOBJECT,)),
                     "paused": (GObject.SIGNAL_RUN_FIRST,
                                GObject.TYPE_NONE,
                                ()),
@@ -490,9 +470,10 @@ class AptTransaction(GObject.GObject):
                     "allow-unauthenticated-changed": (GObject.SIGNAL_RUN_FIRST,
                                                       GObject.TYPE_NONE,
                                                       (GObject.TYPE_BOOLEAN,)),
-                    "remove-obsoleted-depends-changed": (GObject.SIGNAL_RUN_FIRST,
-                                                 GObject.TYPE_NONE,
-                                                 (GObject.TYPE_BOOLEAN,)),
+                    "remove-obsoleted-depends-changed": (
+                        GObject.SIGNAL_RUN_FIRST,
+                        GObject.TYPE_NONE,
+                        (GObject.TYPE_BOOLEAN,)),
                     "locale-changed": (GObject.SIGNAL_RUN_FIRST,
                                        GObject.TYPE_NONE,
                                        (GObject.TYPE_STRING,)),
@@ -515,6 +496,16 @@ class AptTransaction(GObject.GObject):
                                               GObject.TYPE_STRING)),
                     }
 
+    _tid_cache = weakref.WeakValueDictionary()
+
+    def __new__(cls, tid, *args, **kwargs):
+        """Cache transactions with identical tid."""
+        try:
+            return AptTransaction._tid_cache[tid]
+        except KeyError:
+            value = _GObject.__new__(cls, tid, *args, **kwargs)
+            AptTransaction._tid_cache[tid] = value
+            return value
 
     def __init__(self, tid, bus=None):
         GObject.GObject.__init__(self)
@@ -556,8 +547,7 @@ class AptTransaction(GObject.GObject):
         # main signals
         self._signal_matcher = \
             self._iface.connect_to_signal("PropertyChanged",
-                                          self._on_property_changed,
-                                          utf8_strings=True)
+                                          self._on_property_changed)
 
     def _on_name_owner_changed(self, connection):
         """Fail the transaction if the daemon died."""
@@ -678,12 +668,12 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
         """
         def sync_properties(prop_dict):
-            for property_name, value in prop_dict.iteritems():
+            for property_name, value in prop_dict.items():
                 self._on_property_changed(property_name, value)
             if reply_handler:
                 reply_handler(self)
@@ -694,7 +684,8 @@ class AptTransaction(GObject.GObject):
                                error_handler=error_handler)
         else:
             properties = self._proxy.GetAll("org.debian.apt.transaction",
-                                           dbus_interface=dbus.PROPERTIES_IFACE)
+                                            dbus_interface=
+                                            dbus.PROPERTIES_IFACE)
             sync_properties(properties)
 
     @deferable
@@ -713,7 +704,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
          """
@@ -737,7 +728,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.TransactionFailed, dbus.DBusException
         """
@@ -763,7 +754,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.TransactionFailed, dbus.DBusException
         """
@@ -780,7 +771,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.NotAuthorizedError, dbus.DBusException
         """
@@ -799,7 +790,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.NotAuthorizedError, dbus.DBusException
             aptdaemon.errors.ForeignTransaction,
@@ -827,7 +818,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
         """
@@ -835,7 +826,7 @@ class AptTransaction(GObject.GObject):
             _reply_handler = lambda: reply_handler(self)
         else:
             _reply_handler = None
-        self._proxy.Set("org.debian.apt.transaction", 
+        self._proxy.Set("org.debian.apt.transaction",
                         "RemoveObsoletedDepends", remove_obsoleted_depends,
                         dbus_interface=dbus.PROPERTIES_IFACE,
                         reply_handler=_reply_handler,
@@ -857,7 +848,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
         """
@@ -865,7 +856,7 @@ class AptTransaction(GObject.GObject):
             _reply_handler = lambda: reply_handler(self)
         else:
             _reply_handler = None
-        self._proxy.Set("org.debian.apt.transaction", 
+        self._proxy.Set("org.debian.apt.transaction",
                         "AllowUnauthenticated", allow_unauthenticated,
                         dbus_interface=dbus.PROPERTIES_IFACE,
                         reply_handler=_reply_handler,
@@ -890,7 +881,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
          """
@@ -925,7 +916,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
         """
@@ -958,7 +949,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
         """
@@ -988,7 +979,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
         """
@@ -1013,7 +1004,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
          """
@@ -1035,7 +1026,7 @@ class AptTransaction(GObject.GObject):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: aptdaemon.errors.ForeignTransaction, dbus.DBusException
          """
@@ -1071,7 +1062,7 @@ class AptClient(object):
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1092,14 +1083,14 @@ class AptClient(object):
             updated. Updates which require to remove installed packages or to
             install additional packages will be skipped.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
-        :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+        :param defer: Run the method asynchrounsly and return a
+            defer.Deferred. This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1123,14 +1114,14 @@ class AptClient(object):
         :param package_names: List of names of the packages which should be
             installed.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
-        :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+        :param defer: Run the method asynchrounsly and return a
+            defer.Deferred. This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1147,21 +1138,21 @@ class AptClient(object):
         """Create a new transaction to enable a repository.
 
         :param src_type: The type of the repository (deb, deb-src).
-        :param uri: The main repository URI 
+        :param uri: The main repository URI
            (e.g. http://archive.ubuntu.com/ubuntu)
         :param dist: The distribution to use (e.g. stable or lenny-backports).
         :param comps: List of components (e.g. main, restricted).
         :param comment: A comment which should be added to the sources.list.
         :param sourcesfile: (Optoinal) filename in sources.list.d.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return
+            its exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1177,31 +1168,31 @@ class AptClient(object):
 
     @deferable
     @convert_dbus_exception
-    def add_vendor_key_from_keyserver(self, keyid, keyserver, wait=False, 
+    def add_vendor_key_from_keyserver(self, keyid, keyserver, wait=False,
                                       reply_handler=None, error_handler=None):
         """Create a new transaction to download and install the key of a
-        software vendor. The key is used to authenticate packages of the 
+        software vendor. The key is used to authenticate packages of the
         vendor.
 
         :param keyid: The id of the GnuPG key (e.g. 0x0EB12F05)
         :param keyserver: The server to get the key from (e.g.
             keyserver.ubuntu.com)
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
         :returns: An AptTransaction instance.
         """
-        return self._run_transaction("AddVendorKeyFromKeyserver", 
-                                     [keyid,keyserver],
+        return self._run_transaction("AddVendorKeyFromKeyserver",
+                                     [keyid, keyserver],
                                      wait, reply_handler, error_handler)
 
     @deferable
@@ -1213,14 +1204,14 @@ class AptClient(object):
 
         :param path: The absolute path to the key file.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1240,14 +1231,14 @@ class AptClient(object):
 
         :param fingerprint: The fingerprint of the key.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1266,14 +1257,14 @@ class AptClient(object):
         :param force: Force the installation of a .deb-file even if it
             violates the quality standard defined in the packaging policy.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1302,14 +1293,14 @@ class AptClient(object):
 
         :param package_names: The list of package which should be upgraded.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1326,14 +1317,14 @@ class AptClient(object):
 
         :param package_names: The list of packages which should be removed.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1365,14 +1356,14 @@ class AptClient(object):
             package has to be appended to the name separated by a "=", e.g.
             "xterm=272-1".
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1397,14 +1388,14 @@ class AptClient(object):
 
         Corresponds to the ``apt-get -f install`` call.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1425,14 +1416,14 @@ class AptClient(object):
         :param priority: The minimum priority of question that will be
             displayed.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1441,7 +1432,6 @@ class AptClient(object):
         return self._run_transaction("Reconfigure", [packages, priority], wait,
                                      reply_handler, error_handler)
 
-
     @deferable
     @convert_dbus_exception
     def fix_incomplete_install(self, wait=False, reply_handler=None,
@@ -1451,14 +1441,14 @@ class AptClient(object):
 
         Corresponds to the ``dpkg --confgiure -a`` call.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1479,44 +1469,45 @@ class AptClient(object):
             that should be updated only. The other repositories will
             be ignored in this case. Can be either the file name of a snippet
             in /etc/apt/sources.list.d or an absolute path.
- 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
         :returns: An AptTransaction instance.
         """
         if sources_list:
-            return self._run_transaction("UpdateCachePartially", [sources_list],
-                                         wait, reply_handler, error_handler)
+            return self._run_transaction("UpdateCachePartially",
+                                         [sources_list], wait,
+                                         reply_handler, error_handler)
         else:
-            return self._run_transaction("UpdateCache", [], wait, reply_handler,
-                                         error_handler)
+            return self._run_transaction("UpdateCache", [], wait,
+                                         reply_handler, error_handler)
 
     @deferable
     @convert_dbus_exception
-    def enable_distro_component(self, component, wait=False, reply_handler=None,
-                                error_handler=None):
+    def enable_distro_component(self, component, wait=False,
+                                reply_handler=None, error_handler=None):
         """Create a new transaction to enable the component of the
         distribution repository.
 
         :param component: The name of the component, e.g. main or universe.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1530,14 +1521,14 @@ class AptClient(object):
     def clean(self, wait=False, reply_handler=None, error_handler=None):
         """Remove all downloaded files.
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1554,16 +1545,17 @@ class AptClient(object):
 
         :param pkg_name: The package which requires the license
         :param json_token: The oauth token in json format
-        :param server_name: The server name (ubuntu-procduction, ubuntu-staging)
+        :param server_name: The server name (ubuntu-procduction,
+            ubuntu-staging)
 
-        :param wait: if True run the transaction immediately and return its exit
-            state instead of the transaction itself.
+        :param wait: if True run the transaction immediately and return its
+            exit state instead of the transaction itself.
         :param reply_handler: Callback function. If specified in combination
             with error_handler the method will be called asynchrounsouly.
         :param error_handler: Errback function. In case of an error the given
             callback gets the corresponding exception instance.
         :param defer: Run the method asynchrounsly and return a defer.Deferred.
-            This options is only available as an keyword.
+            This options is only available as a keyword.
 
         :raises: dbus.DBusException
 
@@ -1599,7 +1591,7 @@ class AptClient(object):
         else:
             # Iterate on the main loop - we cannot use a sub loop here,
             # since the D-Bus python bindings only work on the main loop
-            context = GObject.main_context_default()
+            context = GLib.main_context_default()
             while not hasattr(deferred, "result"):
                 context.iteration(True)
            # If there has been an error in the helper raise it
@@ -1637,12 +1629,12 @@ class AptClient(object):
         if wait and async:
             deferred_wait = defer.Deferred()
             sig = trans.connect("finished",
-                                lambda trans, exit: \
-                                    (exit != enums.EXIT_UNFINISHED and
-                                     deferred_wait.callback(exit)))
+                                lambda trans, exit:
+                                (exit != enums.EXIT_UNFINISHED and
+                                 deferred_wait.callback(exit)))
             yield trans.run()
             yield deferred_wait
-            GObject.source_remove(sig)
+            GLib.source_remove(sig)
             defer.return_value(trans.exit)
         elif wait:
             yield trans.run()
@@ -1664,7 +1656,7 @@ def get_transaction(tid, bus=None, reply_handler=None, error_handler=None):
     :param error_handler: Errback function. In case of an error the given
         callback gets the corresponding exception instance.
     :param defer: Run the method asynchrounsly and return a defer.Deferred.
-        This options is only available as an keyword.
+        This options is only available as a keyword.
 
     :raises: dbus.DBusException
 
@@ -1679,6 +1671,7 @@ def get_transaction(tid, bus=None, reply_handler=None, error_handler=None):
         trans.sync()
         return trans
 
+
 def get_aptdaemon(bus=None):
     """Get the daemon D-Bus interface.
 
