@@ -173,7 +173,10 @@ class ConsoleClient:
 
     def run(self):
         """Start the console client application."""
-        self._loop.run()
+        try:
+            self._loop.run()
+        except KeyboardInterrupt:
+            pass
 
     def _set_transaction(self, transaction):
         """Monitor the given transaction"""
