@@ -68,6 +68,7 @@ from .worker import (
     DummyWorker,
     trans_only_installs_pkgs_from_high_trust_repos)
 from .loop import mainloop
+from .logger import ColoredFormatter
 
 # Setup i18n
 _ = lambda msg: gettext.dgettext("aptdaemon", msg)
@@ -124,9 +125,9 @@ except:
 else:
     log.addHandler(_syslog_handler)
 _console_handler = logging.StreamHandler()
-_console_formatter = logging.Formatter("%(asctime)s %(name)s [%(levelname)s]: "
-                                       "%(message)s",
-                                       "%T")
+_console_formatter = ColoredFormatter("%(asctime)s %(name)s [%(levelname)s]: "
+                                      "%(message)s",
+                                      "%T")
 _console_handler.setFormatter(_console_formatter)
 log.addHandler(_console_handler)
 #FIXME: Use LoggerAdapter (requires Python 2.6)
@@ -458,6 +459,7 @@ class Transaction(DBusObject):
             self.queue.limbo.pop(self.tid)
         except KeyError:
             pass
+        return False
 
     def _convert_struct(self, lst, signature):
         """Convert a list to a DBus struct with the given signature. Currently
@@ -924,16 +926,34 @@ class Transaction(DBusObject):
     @inline_callbacks
     def _run(self, sender):
         yield self._check_foreign_user(sender)
+        yield self._check_simulated()
         yield self._check_auth()
-        yield self.queue.put(self.tid)
+        self.queue.put(self.tid)
         self.status = enums.STATUS_WAITING
         next_trans = self.after
         while next_trans:
+            yield self._check_simulated()
             yield next_trans._check_auth()
-            yield self.queue.put(next_trans.tid)
+            self.queue.put(next_trans.tid)
             next_trans.status = enums.STATUS_WAITING
             next_trans = next_trans.after
 
+    @inline_callbacks
+    def _check_simulated(self):
+        # Simulate the new transaction if this has not been done before:
+        #FIXME: Compare the simulated timestamp with the time stamp of
+        #       the status and re-simulate the transaction
+        if self.simulated is None:
+            # If there isn't any transaction on the queue we send an early
+            # progress information. Otherwise it juse seems that aptdaemon
+            # hangs since it doesn't send any progress information after the
+            # the transaction has been started
+            if not self.queue.worker.trans:
+                self.progress = 9
+            yield self._simulate_real()
+        else:
+            raise StopIteration
+
     @inline_callbacks
     def _check_auth(self):
         """Check silently if one of the high level privileges has been granted
@@ -1327,22 +1347,9 @@ class TransactionQueue(GObject.GObject):
         log.debug("emitting queue changed")
         self.emit("queue-changed")
 
-    @inline_callbacks
     def put(self, tid):
         """Add an item to the queue."""
         trans = self.limbo.pop(tid)
-        # Simulate the new transaction if this has not been done before:
-        #FIXME: Compare the simulated timestamp with the time stamp of
-        #       the status and re-simulate the transaction
-        if trans.simulated is None:
-            # If there isn't any transaction on the queue we send an early
-            # progress information. Otherwise it juse seems that aptdaemon
-            # hangs since it doesn't send any progress information after the
-            # the transaction has been started
-            if not self.worker.trans:
-                trans.progress = 9
-            yield trans._simulate_real()
-
         if trans._idle_watch is not None:
             GLib.source_remove(trans._idle_watch)
         if self.worker.trans:
@@ -1789,7 +1796,6 @@ class AptDaemon(DBusObject):
         :returns: The D-Bus path of the new transaction object which
             performs this action.
         """
-        #FIXME: Should not be a transaction
         log.info("InstallVendorKeyFromKeyserver() was called: %s %s",
                  keyid, keyserver)
         return self._create_trans(enums.ROLE_ADD_VENDOR_KEY_FROM_KEYSERVER,
@@ -1813,7 +1819,6 @@ class AptDaemon(DBusObject):
         :returns: The D-Bus path of the new transaction object which
             performs this action.
         """
-        #FIXME: Should not be a transaction
         log.info("InstallVendorKeyFile() was called: %s" % path)
         return self._create_trans(enums.ROLE_ADD_VENDOR_KEY_FILE,
                                   sender, kwargs={"path": path})
@@ -1835,7 +1840,6 @@ class AptDaemon(DBusObject):
         :returns: The D-Bus path of the new transaction object which
             performs this action.
         """
-        #FIXME: Should not be a transaction
         log.info("RemoveVendorKey() was called: %s" % fingerprint)
         return self._create_trans(enums.ROLE_REMOVE_VENDOR_KEY,
                                   sender, kwargs={"fingerprint": fingerprint})
@@ -2057,9 +2061,6 @@ class AptDaemon(DBusObject):
         yield policykit1.check_authorization_by_name(sender, action,
                                                      bus=self.bus)
         if iface == APTDAEMON_DBUS_INTERFACE:
-            #FIXME: Support writting configuration to file
-            #FIXME: Should we use a different interface for the
-            #       the APT system configuration?
             if name == "PopConParticipation":
                 self._set_popcon_participation(value)
             elif name == "AutoUpdateInterval":
