@@ -41,7 +41,7 @@ __all__ = ("PKGS_INSTALL", "PKGS_REINSTALL", "PKGS_REMOVE", "PKGS_PURGE",
            "STATUS_RUNNING", "STATUS_LOADING_CACHE", "STATUS_DOWNLOADING",
            "STATUS_COMMITTING", "STATUS_CLEANING_UP", "STATUS_RESOLVING_DEP",
            "STATUS_FINISHED", "STATUS_CANCELLING", "STATUS_QUERY",
-           "STATUS_DOWNLOADING_REPO",
+           "STATUS_DOWNLOADING_REPO", "STATUS_AUTHENTICATING",
            "ROLE_UNSET", "ROLE_INSTALL_PACKAGES", "ROLE_INSTALL_FILE",
            "ROLE_UPGRADE_PACKAGES", "ROLE_UPGRADE_SYSTEM", "ROLE_UPDATE_CACHE",
            "ROLE_REMOVE_PACKAGES", "ROLE_COMMIT_PACKAGES",
