@@ -771,6 +771,7 @@ class _ExpandableDialog(Gtk.Dialog):
         if not buttons:
             buttons = (Gtk.STOCK_CLOSE, Gtk.ResponseType.CLOSE)
         Gtk.Dialog.__init__(self, parent=parent)
+        self.set_title("")
         self.add_buttons(*buttons)
         self.set_resizable(False)
         self.set_border_width(6)
@@ -817,7 +818,15 @@ class _ExpandableDialog(Gtk.Dialog):
         if expander.get_expanded():
             self.set_resizable(True)
             if self._expanded_size:
-                self.resize(*self._expanded_size)
+                # Workaround a random crash during progress dialog expanding
+                # It seems that either the gtk.Window.get_size() method
+                # doesn't always return a tuple or that the
+                # gtk.Window.set_size() method doesn't correctly handle *
+                # arguments correctly, see LP#898851
+                try:
+                    self.resize(self._expanded_size[0], self._expanded_size[1])
+                except (IndexError, TypeError):
+                    pass
         else:
             self._expanded_size = self.get_size()
             self.set_resizable(False)
@@ -1056,7 +1065,7 @@ class AptConfigFileConflictDialog(_ExpandableDialog):
                                    buttons=(_("_Keep"), Gtk.ResponseType.NO,
                                             _("_Replace"),
                                             Gtk.ResponseType.YES))
-        self.set_default_response(Gtk.ResponseType.NO)
+        self.set_default_response(Gtk.ResponseType.YES)
 
     def run(self):
         self.show_all()
