@@ -28,13 +28,13 @@ from defer import Deferred, inline_callbacks, return_value
 from gi.repository import GObject
 from gi.repository import Gio
 from gi.repository import GLib
+from gi.repository import PackageKitGlib as pk
 import dbus
 from dbus.mainloop.glib import DBusGMainLoop
 DBusGMainLoop(set_as_default=True)
 import logging
 import os
 
-from . import pkenums as pk_enums
 
 log = logging.getLogger("AptDaemon.NetMonitor")
 
@@ -45,12 +45,12 @@ class NetworkMonitorBase(GObject.GObject):
 
     __gsignals__ = {"network-state-changed": (GObject.SignalFlags.RUN_FIRST,
                                               None,
-                                              (GObject.TYPE_STRING,))}
+                                              (GObject.TYPE_PYOBJECT,))}
 
     def __init__(self):
         log.debug("Initializing network monitor")
         GObject.GObject.__init__(self)
-        self._state = pk_enums.NETWORK_ONLINE
+        self._state = pk.NetworkEnum.ONLINE
 
     def _set_state(self, enum):
         if self._state != enum:
@@ -78,7 +78,7 @@ class ProcNetworkMonitor(NetworkMonitorBase):
     def __init__(self):
         log.debug("Initializing proc based network monitor")
         NetworkMonitorBase.__init__(self)
-        self._state = pk_enums.NETWORK_OFFLINE
+        self._state = pk.NetworkEnum.OFFLINE
         self._file = Gio.File.new_for_path("/proc/net/route")
         self._monitor = Gio.File.monitor(self._file,
                                          Gio.FileMonitorFlags.NONE,
@@ -110,8 +110,8 @@ class ProcNetworkMonitor(NetworkMonitorBase):
                 elif rows[2] != "00000000":
                     break
             else:
-                return pk_enums.NETWORK_OFFLINE
-        return pk_enums.NETWORK_ONLINE
+                return pk.NetworkEnum.OFFLINE
+        return pk.NetworkEnum.ONLINE
 
     @inline_callbacks
     def get_network_state(self):
@@ -142,7 +142,6 @@ class NetworkManagerMonitor(NetworkMonitorBase):
     def __init__(self):
         log.debug("Initializing NetworkManager monitor")
         NetworkMonitorBase.__init__(self)
-        self._state = pk_enums.NETWORK_UNKNOWN
         self.bus = dbus.SystemBus()
         self.proxy = self.bus.get_object("org.freedesktop.NetworkManager",
                                          "/org/freedesktop/NetworkManager")
@@ -170,7 +169,7 @@ class NetworkManagerMonitor(NetworkMonitorBase):
         if "ActiveConnections" in props:
             if not props["ActiveConnections"]:
                 log.debug("There aren't any active connections")
-                self.state = pk_enums.NETWORK_OFFLINE
+                self.state = pk.NetworkEnum.OFFLINE
             else:
                 yield self.get_network_state()
 
@@ -184,7 +183,7 @@ class NetworkManagerMonitor(NetworkMonitorBase):
     @inline_callbacks
     def _query_network_manager(self):
         """Query NetworkManager about the network state."""
-        state = pk_enums.NETWORK_UNKNOWN
+        state = pk.NetworkEnum.OFFLINE
         try:
             active_conns = yield self.get_dbus_property(self.proxy,
                                                         self.NM_DBUS_IFACE,
@@ -213,7 +212,7 @@ class NetworkManagerMonitor(NetworkMonitorBase):
                         dev_obj, self.NM_DEVICE_DBUS_IFACE, "DeviceType")
                 except dbus.DBusException:
                     log.warning("Failed to determinate network state")
-                    return_value(pk_enums.NETWORK_UNKNOWN)
+                    return_value(pk.NetworkEnum.UNKNOWN)
                 # prioterizse device types, since a bridged GSM/CDMA connection
                 # should be returned as a GSM/CDMA one
                 # The NM_DEVICE_TYPE_* enums are luckly ordered in this sense.
@@ -223,15 +222,15 @@ class NetworkManagerMonitor(NetworkMonitorBase):
 
                 if dev_type in (self.NM_DEVICE_TYPE_GSM,
                                 self.NM_DEVICE_TYPE_CDMA):
-                    state = pk_enums.NETWORK_MOBILE
+                    state = pk.NetworkEnum.MOBILE
                 elif dev_type == self.NM_DEVICE_TYPE_ETHERNET:
-                    state = pk_enums.NETWORK_WIRED
+                    state = pk.NetworkEnum.WIRED
                 elif dev_type == self.NM_DEVICE_TYPE_WIFI:
-                    state = pk_enums.NETWORK_WIFI
+                    state = pk.NetworkEnum.WIFI
                 elif dev_type == self.NM_DEVICE_TYPE_UNKNOWN:
-                    state = pk_enums.NETWORK_OFFLINE
+                    state = pk.NetworkEnum.OFFLINE
                 else:
-                    state = pk_enums.NETWORK_ONLINE
+                    state = pk.NetworkEnum.ONLINE
         return_value(state)
 
     @inline_callbacks
