@@ -14,7 +14,8 @@ __author__ = "Sebastian Heinlein <devel@glatzor.de>"
 
 __all__ = ("DaemonAcquireProgress", "DaemonOpenProgress",
            "DaemonInstallProgress", "DaemonDpkgInstallProgress",
-           "DaemonDpkgRecoverProgress")
+           "DaemonForkProgress", "DaemonDpkgRecoverProgress",
+           "DaemonLintianProgress")
 
 import locale
 import logging
@@ -240,7 +241,6 @@ class DaemonAcquireProgress(apt.progress.base.AcquireProgress):
 
     def media_change(self, medium, drive):
         """Callback for media changes"""
-        #FIXME: make use of DeviceKit/hal
         self.transaction.required_medium = medium, drive
         self.transaction.paused = True
         self.transaction.status = enums.STATUS_WAITING_MEDIUM
@@ -551,7 +551,6 @@ class DaemonForkProgress(object):
             os.putenv("APT_LISTCHANGES_FRONTEND", "none")
             os.putenv("APT_LISTBUGS_FRONTEND", "none")
         else:
-            #FIXME: Should this be a setting?
             os.putenv("TERM", "linux")
         # Run debconf through a proxy if available
         if self.transaction.debconf:
