@@ -203,7 +203,7 @@ class AptDaemonTestCase(unittest.TestCase):
         self.addCleanup(self._kill_process, proc)
         return proc
 
-    def start_session_aptd(self, chroot="/", debug=False):
+    def start_session_aptd(self, chroot="/", debug=True):
         """Start an aptdaemon which listens on the session D-Bus.
 
         :param chroot: path to the chroot
