@@ -429,7 +429,7 @@ class AptWorker(GObject.GObject):
             return False
         # loop
         from_high_trust_repo = []
-        for pkg in self._iterate_packages():
+        for pkg in self._cache.get_changes():
             if pkg.marked_install:
                 for origin in pkg.candidate.origins:
                     if _in_high_trust_repository(pkg.name, origin):
@@ -440,7 +440,7 @@ class AptWorker(GObject.GObject):
     def _get_unauthenticated(self):
         """Return a list of unauthenticated package names """
         unauthenticated = []
-        for pkg in self._iterate_packages():
+        for pkg in self._cache.get_changes():
             if (pkg.marked_install or
                     pkg.marked_downgrade or
                     pkg.marked_upgrade or
@@ -787,7 +787,7 @@ class AptWorker(GObject.GObject):
             resolver = apt.cache.ProblemResolver(self._cache)
         installed_deps = set()
         with self._cache.actiongroup():
-            for pkg in self._iterate_packages():
+            for pkg in self._cache.get_changes():
                 if pkg.marked_delete:
                     installed_deps = self._installed_dependencies(
                         pkg.name, installed_deps)
@@ -1279,7 +1279,6 @@ class AptWorker(GObject.GObject):
         changes_names = []
         # get the additional dependencies
         for pkg in changes:
-            self._iterate_mainloop()
             if (pkg.marked_upgrade and pkg.is_installed and
                     not pkg.name in upgrades):
                 pkg_str = "%s=%s" % (pkg.name, pkg.candidate.version)
@@ -1503,7 +1502,6 @@ class AptWorker(GObject.GObject):
                     # Check if it's an important dependency
                     # See apt-pkg/depcache.cc IsImportantDep
                     # See apt-pkg/pkgcache.cc IsCritical()
-                    # FIXME: Add APT::Install-Recommends-Sections
                     if not (base_dep.rawtype in ["Depends", "PreDepends",
                                                  "Obsoletes", "DpkgBreaks",
                                                  "Conflicts"] or
