@@ -338,7 +338,8 @@ Auto-Installed: 1""")
                                     "force": False})
         self.worker.simulate(trans)
         self.loop.run()
-        self.assertTrue("wrong-file-owner-uid-or-gid" in trans.error.details)
+        self.assertTrue("wrong-file-owner-uid-or-gid" in trans.error.details,
+                        trans.error.details)
         self.assertEqual(trans.error.code, enums.ERROR_INVALID_PACKAGE_FILE,
                          "Lintian failed to detect a broken package")
         # Now allow to install invalid packages
